/* State */
export const cellInitialState = {
    outputs: 0
};
/* Selectors */
import { useSelector } from "react-redux";
export const selectCell = () => useSelector((state) => {
    if (state.cell) {
        return state.cell;
    }
    return { outputs: 0 };
});
/* Actions */
import actionCreatorFactory from "typescript-fsa";
export var ActionType;
(function (ActionType) {
    ActionType["OUTPUTS"] = "cell/OUTPUTS";
    ActionType["EXECUTE"] = "cell/EXECUTE";
})(ActionType || (ActionType = {}));
const actionCreator = actionCreatorFactory('app');
export const cellActions = {
    outputs: actionCreator.async(ActionType.OUTPUTS),
    execute: actionCreator.async(ActionType.EXECUTE),
};
/* Epics */
import { combineEpics } from "redux-observable";
import { map, ignoreElements, tap } from "rxjs/operators";
import { ofAction } from "@datalayer/typescript-fsa-redux-observable";
export const cellEpics = (cellLumino) => {
    const outputsEpic = action$ => action$.pipe(ofAction(cellActions.outputs.started), map(action => {
        return cellActions.outputs.done({
            params: action.payload,
            result: action.payload
        });
    }));
    const executeEpic = action$ => action$.pipe(ofAction(cellActions.execute.started), tap(action => cellLumino.execute()), ignoreElements());
    const loggingEpic = action$ => action$
        .pipe(ofAction(cellActions.outputs.started), 
    //      tap(action => console.log(action.type)),
    ignoreElements());
    return combineEpics(loggingEpic, outputsEpic, executeEpic);
};
/* Reducers */
import { reducerWithInitialState } from "typescript-fsa-reducers";
export const cellReducer = reducerWithInitialState(cellInitialState)
    .case(cellActions.outputs.done, (state, success) => {
    return Object.assign(Object.assign({}, state), { outputs: success.result });
});
//# sourceMappingURL=CellRedux.js.map