/* State */
export const notebookInitialState = {
    outputs: 0
};
/* Selectors */
import { useSelector } from "react-redux";
export const selectCells = () => useSelector((state) => {
    if (state.notebook) {
        return state.notebook;
    }
    return { outputs: 0 };
});
/* Actions */
import actionCreatorFactory from "typescript-fsa";
export var ActionType;
(function (ActionType) {
    ActionType["OUTPUTS"] = "notebook/OUTPUTS";
    ActionType["EXECUTE"] = "notebook/EXECUTE";
})(ActionType || (ActionType = {}));
const actionCreator = actionCreatorFactory('app');
export const cellsActions = {
    outputs: actionCreator.async(ActionType.OUTPUTS),
    execute: actionCreator.async(ActionType.EXECUTE),
};
/* Epics */
import { combineEpics } from "redux-observable";
import { map, ignoreElements } from "rxjs/operators";
import { ofAction } from "@datalayer/typescript-fsa-redux-observable";
export const notebookEpics = (notebookLumino) => {
    const outputsEpic = action$ => action$.pipe(ofAction(cellsActions.outputs.started), map(action => {
        return cellsActions.outputs.done({
            params: action.payload,
            result: action.payload
        });
    }));
    const executeEpic = action$ => action$.pipe(ofAction(cellsActions.execute.started), 
    //      tap(action => notebookLumino.execute()),
    ignoreElements());
    const loggingEpic = action$ => action$
        .pipe(ofAction(cellsActions.outputs.started), 
    //      tap(action => notebook.log(action.type)),
    ignoreElements());
    return combineEpics(loggingEpic, outputsEpic, executeEpic);
};
/* Reducers */
import { reducerWithInitialState } from "typescript-fsa-reducers";
export const notebookReducer = reducerWithInitialState(notebookInitialState)
    .case(cellsActions.outputs.done, (state, success) => {
    return Object.assign(Object.assign({}, state), { outputs: success.result });
});
//# sourceMappingURL=CellsRedux.js.map