/* State */
export const commandsInitialState = {
    outputs: 0
};
/* Selectors */
import { useSelector } from "react-redux";
export const selectCommands = () => useSelector((state) => {
    if (state.commands) {
        return state.commands;
    }
    return { outputs: 0 };
});
/* Actions */
import actionCreatorFactory from "typescript-fsa";
export var ActionType;
(function (ActionType) {
    ActionType["OUTPUTS"] = "commands/OUTPUTS";
    ActionType["EXECUTE"] = "commands/EXECUTE";
})(ActionType || (ActionType = {}));
const actionCreator = actionCreatorFactory('app');
export const commandsActions = {
    outputs: actionCreator.async(ActionType.OUTPUTS),
    execute: actionCreator.async(ActionType.EXECUTE),
};
/* Epics */
import { combineEpics } from "redux-observable";
import { map, ignoreElements } from "rxjs/operators";
import { ofAction } from "@datalayer/typescript-fsa-redux-observable";
export const commandsEpics = (commandsLumino) => {
    const outputsEpic = action$ => action$.pipe(ofAction(commandsActions.outputs.started), map(action => {
        return commandsActions.outputs.done({
            params: action.payload,
            result: action.payload
        });
    }));
    const executeEpic = action$ => action$.pipe(ofAction(commandsActions.execute.started), 
    //      tap(action => commandsLumino.execute()),
    ignoreElements());
    const loggingEpic = action$ => action$
        .pipe(ofAction(commandsActions.outputs.started), 
    //      tap(action => commands.log(action.type)),
    ignoreElements());
    return combineEpics(loggingEpic, outputsEpic, executeEpic);
};
/* Reducers */
import { reducerWithInitialState } from "typescript-fsa-reducers";
export const commandsReducer = reducerWithInitialState(commandsInitialState)
    .case(commandsActions.outputs.done, (state, success) => {
    return Object.assign(Object.assign({}, state), { outputs: success.result });
});
//# sourceMappingURL=CommandsRedux.js.map