/* State */
export const settingsInitialState = {
    outputs: 0
};
/* Selectors */
import { useSelector } from "react-redux";
export const selectSettings = () => useSelector((state) => {
    if (state.settings) {
        return state.settings;
    }
    return { outputs: 0 };
});
/* Actions */
import actionCreatorFactory from "typescript-fsa";
export var ActionType;
(function (ActionType) {
    ActionType["OUTPUTS"] = "settings/OUTPUTS";
    ActionType["EXECUTE"] = "settings/EXECUTE";
})(ActionType || (ActionType = {}));
const actionCreator = actionCreatorFactory('app');
export const settingsActions = {
    outputs: actionCreator.async(ActionType.OUTPUTS),
    execute: actionCreator.async(ActionType.EXECUTE),
};
/* Epics */
import { combineEpics } from "redux-observable";
import { map, ignoreElements } from "rxjs/operators";
import { ofAction } from "@datalayer/typescript-fsa-redux-observable";
export const settingsEpics = (settingsLumino) => {
    const outputsEpic = action$ => action$.pipe(ofAction(settingsActions.outputs.started), map(action => {
        return settingsActions.outputs.done({
            params: action.payload,
            result: action.payload
        });
    }));
    const executeEpic = action$ => action$.pipe(ofAction(settingsActions.execute.started), 
    //      tap(action => settingsLumino.execute()),
    ignoreElements());
    const loggingEpic = action$ => action$
        .pipe(ofAction(settingsActions.outputs.started), 
    //      tap(action => settings.log(action.type)),
    ignoreElements());
    return combineEpics(loggingEpic, outputsEpic, executeEpic);
};
/* Reducers */
import { reducerWithInitialState } from "typescript-fsa-reducers";
export const settingsReducer = reducerWithInitialState(settingsInitialState)
    .case(settingsActions.outputs.done, (state, success) => {
    return Object.assign(Object.assign({}, state), { outputs: success.result });
});
//# sourceMappingURL=SettingsRedux.js.map