/* State */
export const terminalsInitialState = {
    outputs: 0
};
/* Selectors */
import { useSelector } from "react-redux";
export const selectTerminals = () => useSelector((state) => {
    if (state.terminals) {
        return state.terminals;
    }
    return { outputs: 0 };
});
/* Actions */
import actionCreatorFactory from "typescript-fsa";
export var ActionType;
(function (ActionType) {
    ActionType["OUTPUTS"] = "terminals/OUTPUTS";
    ActionType["EXECUTE"] = "terminals/EXECUTE";
})(ActionType || (ActionType = {}));
const actionCreator = actionCreatorFactory('app');
export const terminalsActions = {
    outputs: actionCreator.async(ActionType.OUTPUTS),
    execute: actionCreator.async(ActionType.EXECUTE),
};
/* Epics */
import { combineEpics } from "redux-observable";
import { map, ignoreElements } from "rxjs/operators";
import { ofAction } from "@datalayer/typescript-fsa-redux-observable";
export const terminalsEpics = (terminalsLumino) => {
    const outputsEpic = action$ => action$.pipe(ofAction(terminalsActions.outputs.started), map(action => {
        return terminalsActions.outputs.done({
            params: action.payload,
            result: action.payload
        });
    }));
    const executeEpic = action$ => action$.pipe(ofAction(terminalsActions.execute.started), 
    //      tap(action => terminalsLumino.execute()),
    ignoreElements());
    const loggingEpic = action$ => action$
        .pipe(ofAction(terminalsActions.outputs.started), 
    //      tap(action => console.log(action.type)),
    ignoreElements());
    return combineEpics(loggingEpic, outputsEpic, executeEpic);
};
/* Reducers */
import { reducerWithInitialState } from "typescript-fsa-reducers";
export const terminalsReducer = reducerWithInitialState(terminalsInitialState)
    .case(terminalsActions.outputs.done, (state, success) => {
    return Object.assign(Object.assign({}, state), { outputs: success.result });
});
//# sourceMappingURL=TerminalsRedux.js.map